#!/usr/bin/perl
use strict;
use warnings;
use Math::CDF qw(:all);

# This is a perl script that will be used by the bash script, 7_b_run_binomial.sh, to calculate the binomial p-value. This calculation is a statistical test that considers the total amount of reads in both the B and NoB datasets, and evaluates the likelyhood of getting the observed number of reads aligned to a position by random chance. The portion of NoB reads can be calculated by summing the average genome coverage of the B and NoB sample, and then finding the portion of this that is from the NoB sample: (NoB average coverage)/(NoB + B average coverage).

open( OUTPUT, '>', "<OUTPUT_scaled.ratio.mpileup_binomial>" ); 
open( FILE, "<ENTER_scaled.ratio.mpileup>" );
while (<FILE>) {
    chomp;
    my @array = ( split(/\s/) );
    my $col_1 = $array[0];
    my $col_2 = $array[1];
    my $col_3 = $array[2];
    my $col_4 = $array[3];
    my $col_5 = $array[4];
    my $col_6 = $array[5];
    my $col_7 = $array[6];
    my $col_8 = $array[7];
    my $col_9 = $array[8];
    my $coverage_sum = $col_4 + $col_7;
    $coverage_sum ||= 1;
    print OUTPUT $col_1, "\t", $col_2, "\t", $col_3, "\t", $col_4, "\t", $col_5, "\t", $col_6, "\t", $col_7, "\t", $col_8, "\t", $col_9, "\t", pbinom($col_7, $coverage_sum, <ENTER_PORTION_OF_NoB_READS>), "\n" ; # calculates the binomial p-value
}
close( FILE );
close( OUTPUT );



