#!/bin/bash
#SBATCH -t 240:00:00
#SBATCH --ntasks=1
#SBATCH -N 1
#SBATCH --mem=65000
#SBATCH --share
#SBATCH --output=output_bedtools_intersect_genes_%j.out


# This script uses bedtools intersect to find overlap between the B blocks and genes listed in a gene annotation file. 

bedtools intersect -wa -a <Enter_gene_annotation.gff3> -b <Enter_SAMPLE1_IGVready.bed> > <OUTPUT_Genes_overlapping_SAMPPLE1_blocks.gff3>

# If you have used multiple individuals/datasets and have a "core" block set, you can add the following to determine which genes/gene fragments are shared across the different Bs. 

bedtools intersect -wa -a <Enter_gene_annotation.gff3> -b <ENTER_core_blocks.bed> > <OUTPUT_Genes_overlapping_core_blocks.gff3>



# To take the resulting .gff3 file(s) produced above and make a more reader-friendly list of genes, the following scripts were used. NOTE: this may need to be modified for different gene annotation files.

awk '{if ($3 == "mRNA") print $0}' <ENTER_Genes_overlapping_SAMPPLE1_blocks.gff3> | awk '{split($0,a,"Note=PREDICTED:"); print a[2]}' | sort -u > <OUTPUT_List_of_gene_names_SAMPLE1.txt>

awk '{if ($3 == "mRNA") print $0}' <ENTER_Genes_overlapping_core_blocks.gff3> | awk '{split($0,a,"Note=PREDICTED:"); print a[2]}' | sort -u > <OUTPUT_List_of_gene_names_core.txt>



# The lists produced from the previous step will include multiple lines for the transcript variants of a gene. The following was used to remove multiple entries for each transcript variant and instead have one entry per gene.

sed -i -- 's/, transcript variant .*,/,/g' List_of_gene_names*

sort -u <ENTER_List_of_gene_names_SAMPLE1.txt> > <OUTPUT_List_of_gene_names_SAMPLE1_unique.txt>

sort -u <ENTER_List_of_gene_names_core.txt> > <OUTPUT_List_of_gene_names_core_unique.txt>



# Now the number of genes can be determined by counting the number of lines in the file produced by the previous step.

wc -l <ENTER_List_of_gene_names_SAMPLE1_unique.txt> > <OUTPUT_number_of_genes_SAMPLE1.txt>
wc -l <ENTER_List_of_gene_names_core_unique.txt> > <OUTPUT_number_of_genes_core.txt>

